//	Copyright  1995 Apple Computer, Inc. All rights reserved.
//	Release Version:	$ 1.0 d11 $

//=======================================================================
#ifndef _EVENTFRAME_
#include "EventFrm.h"			// CEventFrame
#endif

#ifndef EVENTPRT_H
#include "EventPrt.h"			// CEventPart
#endif

#ifndef CONSTANT_H
#include "Constant.h"			// my menu command numbers
#endif

// ----- Framework Layer -----
#ifndef FWUTIL_H
#include "FWUtil.h"				// FW_CFacetContext, FW_Beep()
#endif

// ----- Graphic Includes -----
#ifndef FWRECT_H
#include <FWRect.h>				// FW_CRect
#endif

#ifndef FWRECSHP_H
#include "FWRecShp.h"			// FW_CRectShape
#endif

//========================================================================================
#ifdef FW_BUILD_MAC
#pragma segment Event
#endif

//========================================================================================
CEventFrame::CEventFrame(Environment* ev, ODFrame* odFrame, 
									FW_CPresentation* presentation, CEventPart* eventPart)
  : FW_CFrame(ev, odFrame, presentation, eventPart)
{
}

//----------------------------------------------------------------------------------------
CEventFrame::~CEventFrame()
{
}

//----------------------------------------------------------------------------------------
void 
CEventFrame::Draw(Environment *ev, ODFacet* odFacet, ODShape* invalidShape)	// Override
{
	FW_CViewContext context(ev, this, odFacet, invalidShape);
	FW_CRect frameRect = this->GetBounds(ev);

	// fill frame with green  
	FW_CRectShape rectShape(frameRect, FW_kFill);
	rectShape.GetInk()->SetForeColor(FW_kRGBGreen);
	rectShape.Render(context);
}

//----------------------------------------------------------------------------------------
FW_Boolean 
CEventFrame::DoMouseDown(Environment* ev, const FW_CMouseEvent& theMouseEvent)
{	
	FW_UNUSED(ev);
	FW_Boolean handledEvent = FALSE;

	// get position of mouse click in case you need it
	FW_CPoint position = theMouseEvent.GetMousePosition(ev, FW_CMouseEvent::kFrame);
	this->GetContentView(ev)->FrameToViewContent(ev, position);
	// use mouse position here if you need it
	
	// check for triple-clicks
	if (theMouseEvent.GetNumberOfClicks(ev) == 3) {
		FW_Beep();
		handledEvent = TRUE;
		}
	return handledEvent;
}

//----------------------------------------------------------------------------------------
FW_Boolean 
CEventFrame::DoCharKey(Environment* ev, const FW_CCharKeyEvent& event)
{
	FW_Boolean handledEvent = FALSE;
	char c = event.GetChar(ev);
	if (c == 'b') {
		FW_Beep();				// do something with the character
		handledEvent = TRUE;
		}
	return handledEvent;
}
  
//--------------------------------------------------------------------------------------
FW_Boolean 
CEventFrame::DoVirtualKey(Environment* ev, 
									const FW_CVirtualKeyEvent& theVirtualKeyEvent)
{
	FW_Boolean handledKey = TRUE;
	if (theVirtualKeyEvent.GetKeyboardState(ev) == FW_CVirtualKeyEvent::kKeyDown)
		;	// do something if any key down
		
	short keyCode = theVirtualKeyEvent.GetKeyCode(ev);
	short shiftedCode = keyCode >> 8;	// bug in ODF
	switch (shiftedCode) {
		case FW_BACKSPACE:				// Mac delete
			FW_Beep();
			break;
			
		case FW_RIGHT:					// right-arrow
			FW_Beep();
			break;
			
		case FW_ENTER:					// enter key
			FW_Beep(); FW_Beep();
			break;
			
		default:
			handledKey = FALSE;
	}	// switch
	return handledKey;
}
